@@ -16,13 +16,13 @@ class PKCS7Encoder():
                     'and 99')
         self.block_size = block_size
 
-    def encode(self, text):
-        text_length = len(text)
+    def get_padding(self, text_length):
         amount_to_pad = self.block_size - (text_length % self.block_size)
-        if amount_to_pad == 0:
-            amount_to_pad = self.block_size
         pad = unhexlify('%02d' % amount_to_pad)
-        return text + pad * amount_to_pad
+        return pad * amount_to_pad
+
+    def encode(self, text):
+        return text + self.get_padding(len(text))
 
     def decode(self, text):
         pad = int(hexlify(text[-1]))
